.. _calcos:

**************************************
Primary User Interface: calcos()
**************************************

.. currentmodule:: calcos

.. automodule:: calcos

.. autofunction:: calcos

.. autoclass:: Association

.. autoclass:: Observation
